############################
#Code to reproduce results from Sullivan et al. Diversity and carbon storage across the tropical forest biome. Scientific Reports
#This file has code to:
	#1) Produce Fig.1 (1 ha relationship)
	#2) Run Kendall's tau correlations
	#3) Examine variation in diversity and carbon among continents
	#4) Run OLS and SAR models
	#5) Produce Fig. 4 (0.04 ha relationship)

#Note that set.seed has not been used - thus bootstrap results may differ very slightly from results reported in the paper

#Set working directory, e.g.
setwd("Data_package")

#Load required packages
library(MASS)
library(multcomp)
library(spdep)
library(MuMIn)
library(RColorBrewer)
library(TeachingDemos)

#Load 1 ha data
plots<-read.csv("Data_1ha.csv",header=T,as.is=T,na.strings="#N/A")

#Convert AGBChave to carbon
plots$Carbon<-0.471*plots$AGBChave

#Get colour pallete for figures
col.seq<-brewer.pal(3,"Dark2")

### Diversity-carbon relationship across the biome
#Will need to adjust plot window size to make it look pretty
par(fig=c(0,0.85,0,0.85))
par(mar=c(5,5,1,0.5))
par(las=1)
plot(plots$Carbon~plots$SpeciesRich,ylab=expression(paste("Carbon (Mg.",ha^-1,")")),xlab="Species richness",type="n")
with(plots[plots$continent=="Africa",],points(Carbon~SpeciesRich,pch=15,col=col.seq[2]))
with(plots[plots$continent=="South America",],points(Carbon~SpeciesRich,pch=16,col=col.seq[1]))
with(plots[plots$continent=="Asia",],points(Carbon~SpeciesRich,pch=17,col=col.seq[3]))
#points(preds~pred.plots$SpeciesRich,type="l",lwd=2)
legend(190,350,legend=c("South America (SA)","Africa (AF)","Asia (AS)"),pch=c(16,15,17),col=c(col.seq[1],col.seq[2],col.seq[3]),cex=0.75)
par(fig=c(0,0.85,0.62,1), new=TRUE)
boxplot(list(plots$SpeciesRich[plots$continent=="Asia"],plots$SpeciesRich[plots$continent=="Africa"],plots$SpeciesRich[plots$continent=="South America"]), horizontal=TRUE, axes=FALSE,col=c(col.seq[3],col.seq[2],col.seq[1]))
text(150,1,"AS",cex=0.75,col="white")
text(65,2,"AF",cex=0.75,col="white")
text(120,3,"SA",cex=0.75,col="white")
par(fig=c(0.65,1,0,0.85),new=TRUE)
boxplot(list(plots$Carbon[plots$continent=="South America"],plots$Carbon[plots$continent=="Africa"],plots$Carbon[plots$continent=="Asia"]), axes=FALSE,col=c(col.seq[1],col.seq[2],col.seq[3]))
text(3,220,"AS",cex=0.75,col="white")
text(2,202,"AF",cex=0.75,col="white")
text(1,150,"SA",cex=0.75,col="white")

#Look at pan-tropical bivariate diversity-carbon relationship
#Weight by forest cover - from Saatchi et al 2011 PNAS, using 30% cover values (AF=26.65%, SA = 53.25%, AS = 20.04%)
#weights are how many plots we should have if we had sampled evenly by forest cover divided by how may plots we actually have
wv<-ifelse(plots$continent=="South America",191.70/158,ifelse(plots$continent=="Africa",95.96/162,72.13/40))
mod<-lm(log(Carbon)~SpeciesRich,data=plots,weights=wv)
summary(mod)

#Kendall's tau correlations
c1<-with(plots[plots$continent=="South America",],cor.test(Carbon,SpeciesRich,method="k"))
c2<-with(plots[plots$continent=="Africa",],cor.test(Carbon,SpeciesRich,method="k"))
c3<-with(plots[plots$continent=="Asia",],cor.test(Carbon,SpeciesRich,method="k"))

k.cor<-data.frame("Continent"=c("South America","Africa","Asia"),"Tau"=round(c(c1$estimate,c2$estimate,c3$estimate),3),"P"=round(c(c1$p.value,c2$p.value,c3$p.value),3))


#Variation in diversity and carbon among continents
#Split data by continent so can run functions on each continent
dat<-split(plots,plots$continent)
#Define function to randomly sample data with replacement
boot.fun<-function(x,n=10000){
m.vec<-c()
for(i in 1:n){
b.samp<-sample(x,length(x),replace=T)
m.vec[i]<-mean(b.samp)
}
LCL<-quantile(m.vec,0.025)
UCL<-quantile(m.vec,0.975)
res<-paste(round(LCL,0),round(UCL,0),sep=" - ")
return(res)
}

#Define wrapper function to do bootstrapping and return mean and 95% CIs
boot.wrap<-function(x){
bs<-boot.fun(x)
bs<-paste("(",bs,")",sep="")
mv<-round(mean(x),0)
res<-paste(mv,bs,sep=" ")
return(res)
}

#Run function for each variable
cont.sum<-rbind(
c("Carbon (Mg/ha)",sapply(dat,function(x)boot.wrap(x$Carbon))),
c("Fisher's alpha",sapply(dat,function(x)boot.wrap(x$FishersAlpha))),
c("Species richness / ha",sapply(dat,function(x)boot.wrap(x$SpeciesRich))),
c("SpRch / 300 stems",sapply(dat,function(x)boot.wrap(na.omit(as.numeric(x$Speciesper300stems))))),
c("Genus richness / ha",sapply(dat,function(x)boot.wrap(x$GenusRich))),
c("GnRch / 300 stems",sapply(dat,function(x)boot.wrap(na.omit(as.numeric(x$Generaper300stems))))),
c("Family richness / ha",sapply(dat,function(x)boot.wrap(x$FamilyRich))),
c("FamRch / 300 stems",sapply(dat,function(x)boot.wrap(na.omit(as.numeric(x$Familiesper300stems))))))

#Test whether variables differ significantly among continents
plots2<-plots
plots2$continent<-as.factor(plots2$continent)
mf1<-lm(log(Carbon)~continent,data=plots2)
mf2<-lm(sqrt(FishersAlpha)~continent,data=plots2)
mf3<-glm.nb(SpeciesRich~continent,data=plots2)
mf4<-lm(as.numeric(Speciesper300stems)~continent,data=plots2)
mf5<-glm.nb(GenusRich~continent,data=plots2)
mf6<-lm(as.numeric(Generaper300stems)~continent,data=plots2)
mf7<-glm.nb(FamilyRich~continent,data=plots2)
mf8<-lm(as.numeric(Familiesper300stems)~continent,data=plots2)

#Different letters indicate significant differences
mc<-rbind(cld(glht(mf1,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf2,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf3,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf4,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf5,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf6,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf7,linfct=mcp(continent="Tukey")))$mcletters$Letters,
cld(glht(mf8,linfct=mcp(continent="Tukey")))$mcletters$Letters)

cont.sum<-as.data.frame(cbind(cont.sum,mc))
names(cont.sum)<-c("Variable","Africa","Asia","South America","Africa.sig","Asia.sig","South America.sig")

#####
#Examine diversity-carbon relationship controlling for other variables
#NOTE: Lat long only to 2 dp in this file, so results of SAR will differ slightly to those in paper
#Need to allow for zero distances between plots
set.ZeroPolicyOption(TRUE)

#Collapse variation in soil texture into two axes
soil.pca<-prcomp(plots[,32:34]) 
plots$PCA1<-soil.pca$x[,1] 
plots$PCA2<-soil.pca$x[,2]

#Create coords object
coords<-as.matrix(cbind(plots$Long,plots$Lat))
#Scale predictor variables
plots[,c(10:12,14:23,30,31,35:37,39,40)]<-scale(plots[,c(10:12,14:23,30,31,35:37,39,40)])

#Set diversity variable
resp<-"SpeciesRich"

#Set continent
cont="South America"

#Create formula
form<-as.formula(paste("log(Carbon)~",resp,"+MAT+MAP+CWD+PCA1+PCA2+TEB.HWSDbest+C.N.HWSDbest"))

#Fit OLS model
glob.mod<-lm(form,data=plots[plots$continent==cont,],na.action="na.fail")
adj.r<-summary(glob.mod)$adj.r.squared
coef<-summary(glob.mod)$coefficients

#Select neighbourhood distance that gives lowest AIC value for SAR model
aics<-c()
dist.seq<-seq(20,1000,by=20)
for (i in 1:length(dist.seq)){
nb<-dnearneigh(coords[plots$continent==cont,],0,dist.seq[i],longlat=T)
#Spatial weights with coding style "W" (row standardized)
nbw<-nb2listw(nb,  style="W", zero.policy=TRUE)
#SAR error model
sp.mod<-errorsarlm(glob.mod, data=plots[plots$continent==cont,],listw=nbw,zero.policy=TRUE,na.action=na.fail)
aics[i]<-AIC(sp.mod)
}
best.neigh<-dist.seq[grep(min(aics),aics)]
#Run with best neighbourhood size
nb<-dnearneigh(coords[plots$continent==cont,],0,best.neigh,longlat=T)
nbw<-nb2listw(nb,  style="W", zero.policy=TRUE)
sp.mod<-errorsarlm(glob.mod, data=plots[plots$continent==cont,],listw=nbw,zero.policy=TRUE,na.action=na.fail)
sp.sum<-summary(sp.mod,Nagelkerke=TRUE)
sp.coef<-sp.sum$Coef

#Run all simplifications of model
dd1<-dredge(glob.mod)
dd2<-dredge(sp.mod)

#Model averaging
avgmod1<- model.avg(dd1, cumsum(weight) <= .95)
avgmod2<- model.avg(dd2, cumsum(weight) <= .95)

#Collate OLS results
a1<-summary(avgmod1)$coefmat.subset #Note in older versions of MuMIn this is just coefmat
b<-summary(avgmod1)$importance
ols<-cbind(a1,b[match(dimnames(a1)[[1]],names(b))])
ols<-as.data.frame(ols)
ols$Continent<-cont
ols$Response<-resp
ols$Mod<-"OLS"
names(ols)[6]<-"Sum AIC weight"

#Collate SAR results
a2<-summary(avgmod2)$coefmat.subset #Note in older versions of MuMIn this is just coefmat
b<-summary(avgmod2)$importance
sar<-cbind(a2,b[match(dimnames(a2)[[1]],names(b))])
sar<-as.data.frame(sar)
sar$Continent<-cont
sar$Response<-resp
sar$Mod<-"SAR"
names(sar)[5]<-"Sum AIC weight"

############
#Within plot analysis
#Load subplot data
subplot<-read.csv("Data_subplot.csv",header=T,as.is=T,na.string="NA")
#Convert AGB to carbon
subplot$Carbon<-0.471*subplot$AGBChave

#Split by plot so can run functions on each plot
s1<-split(subplot,subplot$plotviewid)

#Run regressions controlling for stem density in each plot
beta.vec<-sapply(s1,function(x)as.numeric(coef(lm(log(AGBChave)~log(SpeciesRich)+log(stems)+I(log(stems)^2),data=x))[2]))
#Get continent ID for each plot
cont.list<-sapply(s1,function(x)unique(x$continent))

#Mean across plots
m.all<-mean(beta.vec)
#Bootstrap to find 95% CIs
m.samp<-c()
for(i in 1:10000){
b2<-beta.vec[sample(1:length(beta.vec),length(beta.vec),replace=T)]
m.samp[i]<-mean(b2)
}
LCL<-quantile(m.samp,0.025)
UCL<-quantile(m.samp,0.975)

#Define as a function so can run on all continents
b.func<-function(x){
m.all2<-mean(x)
m.samp<-c()
for(i in 1:10000){
b2<-x[sample(1:length(x),length(x),replace=T)]
m.samp[i]<-mean(b2)
}
LCL2<-quantile(m.samp,0.025)
UCL2<-quantile(m.samp,0.975)
return(c(m.all2,LCL2,UCL2))
}


#Run on each continent
Af<-b.func(beta.vec[cont.list=="Africa"])
As<-b.func(beta.vec[cont.list=="Asia"])
Sa<-b.func(beta.vec[cont.list=="South America"])

#Make figure
#Need to define function to make subplot
splot.fun<-function(){
plot(c(m.all,Sa[1],Af[1],As[1]),ylim=c(-0.75,0.6),ylab="",xlab="",xlim=c(0.5,4.5),xaxt="n",yaxt="n",pch=16,cex=0.75,las=1,col=c("black",col.seq[1],col.seq[2],col.seq[3]),cex.axis=0.75)
arrows(1,LCL,1,UCL,code=3,angle=90,length=0.01)
arrows(2,Sa[2],2,Sa[3],code=3,angle=90,length=0.01,col=col.seq[1])
arrows(3,Af[2],3,Af[3],code=3,angle=90,length=0.01,col=col.seq[2])
arrows(4,As[2],4,As[3],code=3,angle=90,length=0.01,col=col.seq[3])
lines(c(0,10),c(0,0))
axis(side=2,at=c(-0.6,-0.3,0,0.3,0.6),las=1,cex.axis=0.75,tck=-0.03,mgp=c(3,0.2,0))
mtext(expression(beta),cex=1,side=2,line=1.3,las=2)
mtext("All",cex=0.75,side=1,line=0.5,at=1,las=2)
mtext("South America",cex=0.75,side=1,line=0.5,at=2,las=2)
mtext("Africa",cex=0.75,side=1,line=0.5,at=3,las=2)
mtext("Asia",cex=0.75,side=1,line=0.5,at=4,las=2)
}

#Then plot histogram
dev.off()
par(mar=c(4,4,0,1))
#all data
a<-hist(beta.vec,col=col.seq[3],ylim=c(0,130),xlim=c(-6,6),ylab="Frequency",xlab=expression(beta),main="")#Asia
#Remove Asia
hist(beta.vec[!cont.list=="Asia"],breaks=a$breaks,add=T,col=col.seq[2])#Africa
#Remove Asia and Africa
hist(beta.vec[!cont.list%in%c("Asia","Africa")],breaks=a$breaks,add=T,col=col.seq[1])#South America
#Add text to bars
text(0.5,10,"SA",col="white")
text(0.5,60,"AF",col="white")
text(0.5,95,"AS",col="white")
#Add subplot
subplot(splot.fun(),-3.7,110,c(1.25,1.25))
legend(1.5,120,c("South America (SA)","Africa (AF)","Asia (AS)"),fill=col.seq,cex=0.75)
lines(c(0,0),c(-10,110),lwd=2)
